@@ -18,13 +18,17 @@ Disable a policy:
   example cli: <<-EOT
 Disable a policy:
 
-    razor delete-policy --name example
+    razor disable-policy --name example
+
+With positional arguments, this can be shortened::
+
+    razor disable-policy example
   EOT
 
 
   authz '%{name}'
   attr  'name', type: String, required: true, references: Razor::Data::Policy,
-                help: _('The name of the policy to disable.')
+                position: 0, help: _('The name of the policy to disable.')
 
   def run(request, data)
     policy = Razor::Data::Policy[:name => data['name']]
